# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulpcore
from pulpcore.client.pulpcore.models.task_group_response import TaskGroupResponse  # noqa: E501
from pulpcore.client.pulpcore.rest import ApiException

class TestTaskGroupResponse(unittest.TestCase):
    """TaskGroupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TaskGroupResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulpcore.models.task_group_response.TaskGroupResponse()  # noqa: E501
        if include_optional :
            return TaskGroupResponse(
                pulp_href = '0', 
                description = '0', 
                all_tasks_dispatched = True, 
                waiting = 56, 
                skipped = 56, 
                running = 56, 
                completed = 56, 
                canceled = 56, 
                failed = 56, 
                canceling = 56, 
                group_progress_reports = [
                    pulpcore.client.pulpcore.models.group_progress_report_response.GroupProgressReportResponse(
                        message = '0', 
                        code = '0', 
                        total = 56, 
                        done = 56, 
                        suffix = '0', )
                    ], 
                tasks = [
                    pulpcore.client.pulpcore.models.minimal_task_response.MinimalTaskResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        state = '0', 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        worker = '0', )
                    ]
            )
        else :
            return TaskGroupResponse(
                description = '0',
                all_tasks_dispatched = True,
        )

    def testTaskGroupResponse(self):
        """Test TaskGroupResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
