# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulpcore
from pulpcore.client.pulpcore.models.status_response import StatusResponse  # noqa: E501
from pulpcore.client.pulpcore.rest import ApiException

class TestStatusResponse(unittest.TestCase):
    """StatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StatusResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulpcore.models.status_response.StatusResponse()  # noqa: E501
        if include_optional :
            return StatusResponse(
                versions = [
                    pulpcore.client.pulpcore.models.version_response.VersionResponse(
                        component = '0', 
                        version = '0', )
                    ], 
                online_workers = [
                    pulpcore.client.pulpcore.models.worker_response.WorkerResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ], 
                online_content_apps = [
                    pulpcore.client.pulpcore.models.content_app_status_response.ContentAppStatusResponse(
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ], 
                database_connection = null, 
                redis_connection = null, 
                storage = null
            )
        else :
            return StatusResponse(
                versions = [
                    pulpcore.client.pulpcore.models.version_response.VersionResponse(
                        component = '0', 
                        version = '0', )
                    ],
                online_workers = [
                    pulpcore.client.pulpcore.models.worker_response.WorkerResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                online_content_apps = [
                    pulpcore.client.pulpcore.models.content_app_status_response.ContentAppStatusResponse(
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                database_connection = null,
        )

    def testStatusResponse(self):
        """Test StatusResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
